==> haskell-hspec-discover-2.7.0-4-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hspec-discover.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hspec-discover
version: 2.7.0
id: hspec-discover-2.7.0-1HY7ubdFVlOJwxiCxcMmh6
key: hspec-discover-2.7.0-1HY7ubdFVlOJwxiCxcMmh6
license: MIT
copyright: (c) 2012-2019 Simon Hengel
maintainer: Simon Hengel <sol@typeful.net>
author: Simon Hengel <sol@typeful.net>
stability: experimental
homepage: http://hspec.github.io/
synopsis: Automatically discover and run Hspec tests
description:
    Automatically discover and run Hspec tests
    .
    <http://hspec.github.io/hspec-discover.html>
category: Testing
abi: 8a0dccec0e1f871b661b985a37957d87
exposed-modules:
    Test.Hspec.Discover.Config Test.Hspec.Discover.Run
    Test.Hspec.Discover.Sort
hidden-modules: Paths_hspec_discover
import-dirs: /usr/lib/ghc-8.6.5/site-local/hspec-discover-2.7.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/hspec-discover-2.7.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/hspec-discover-2.7.0
hs-libraries: HShspec-discover-2.7.0-1HY7ubdFVlOJwxiCxcMmh6
depends:
    base-4.12.0.0 directory-1.3.3.0 filepath-1.4.2.1
haddock-interfaces: /usr/share/doc/haskell-hspec-discover/html/hspec-discover.haddock
haddock-html: /usr/share/doc/haskell-hspec-discover/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hspec-discover-2.7.0-5-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hspec-discover.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hspec-discover
version: 2.7.0
id: hspec-discover-2.7.0-LggzGiepFuzK6n0BKiz3mA
key: hspec-discover-2.7.0-LggzGiepFuzK6n0BKiz3mA
license: MIT
copyright: (c) 2012-2019 Simon Hengel
maintainer: Simon Hengel <sol@typeful.net>
author: Simon Hengel <sol@typeful.net>
stability: experimental
homepage: http://hspec.github.io/
synopsis: Automatically discover and run Hspec tests
description:
    Automatically discover and run Hspec tests
    .
    <http://hspec.github.io/hspec-discover.html>
category: Testing
abi: f413600f7d4c115640c33fca17e58b9a
exposed-modules:
    Test.Hspec.Discover.Config Test.Hspec.Discover.Run
    Test.Hspec.Discover.Sort
hidden-modules: Paths_hspec_discover
import-dirs: /usr/lib/ghc-8.6.5/site-local/hspec-discover-2.7.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/hspec-discover-2.7.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/hspec-discover-2.7.0
hs-libraries: HShspec-discover-2.7.0-LggzGiepFuzK6n0BKiz3mA
depends:
    base-4.12.0.0 directory-1.3.3.0 filepath-1.4.2.1
haddock-interfaces: /usr/share/doc/haskell-hspec-discover/html/hspec-discover.haddock
haddock-html: /usr/share/doc/haskell-hspec-discover/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
